@@ -48,7 +48,7 @@ class _GlobalPointerNet(nn.Module):
 
 class _NamedEntityRecognizer(object):
     """
-    命名实体识别器
+    Named Entity Recognizer
     """
     def __init__(self, maxlen, c_size, id2c, device, tokenizer, model_base):
         self.maxlen = maxlen
@@ -56,10 +56,17 @@ class _NamedEntityRecognizer(object):
         self.id2c = id2c
         self.device = device
         self.tokenizer = tokenizer
-        self.model_base = model_base.to(self.device)
+        self.model_base = model_base
 
     def recognize(self, text, threshold=0):
-        
+        """
+        Args:
+            text (str): input sentence
+            threshold (int): threshold score to filter out recognized entity with low confidence score
+                Default: 0
+        Returns:
+            entities (list): list of tuples with recognized entity. The format is [(start_id, end_id, entity_class), ...]
+        """
         self.model_base.eval()
         text = text[0:self.maxlen]
  
@@ -98,14 +105,15 @@ class _NamedEntityRecognizer(object):
 
     def predict_to_file(self, in_file, out_file):
         """
-        预测到文件
-        可以提交到 https://tianchi.aliyun.com/dataset/dataDetail?dataId=95414
+        Args:
+            in_file (str): path of input json file
+            out_file (str): path of output json file which can be submitted to CBLUE
         """
         data = json.load(open(in_file))
         for d in data:
             d['entities'] = []
             entities = self.recognize(d['text'])
-            print(entities)
+            #print(entities)
             for e in entities:
                 d['entities'].append({
                     'start_idx': e[0],
@@ -134,6 +142,8 @@ def load_NNER(model_save_path='./checkpoint/macbert-large_dict.pth',
             Default: 9
         id2c (dictionary, optional): mapping between id and entity class
             Default: _id2c
+    Returns:
+        NNER (class _NamedEntityRecognizer): the pretrained NNER model
     '''
     device = torch.device('cuda') if torch.cuda.is_available() else torch.device('cpu')
     print("Using {} device".format(device))
@@ -154,60 +164,8 @@ def load_NNER(model_save_path='./checkpoint/macbert-large_dict.pth',
     state_dict = torch.load(model_save_path, map_location=device)
     # multi-gpu -> 1 gpu
     model_base.load_state_dict({k.replace('module.', ''): v for k, v in state_dict.items()})
-    NER = _NamedEntityRecognizer(maxlen, c_size, id2c, device, tokenizer, model_base)
-    return NER
-
-"""
-def infer(in_file, out_file='./CMeEE_test_answer.json', 
-            model_save_path='./checkpoint/68.2796_macbert_large/macbert-large', 
-            maxlen=512, c_size=9, id2c=_id2c):
-    '''
-    Args:
-        in_file (string): path of input file
-        out_file (string, optional): path of output file
-            Default: './CMeEE_test_answer.json'
-        model_save_path (string, optional): path of pretrained model
-            Default: './checkpoint/68.2796_macbert_large/macbert-large'
-        maxlen (int, optional): max length of sentence
-            Default: 512
-        c_size (int, optional): number of c???
-            Default: 9
-        id2c (dictionary, optional): mapping between id and c???
-            Default: _id2c
-    '''
-    if not os.path.exists(in_file):
-        print("[ERROR] in_file does not exist!")
-        return
-    if not os.path.isfile(in_file):
-        print("[ERROR] in_file is not a file!")
-        return
-    out_dir = os.path.dirname(out_file)
-    if not os.path.exists(out_dir):
-        os.makedirs(out_dir)
-
-    device = torch.device('cuda') if torch.cuda.is_available() else torch.device('cpu')
-    print("Using {} device".format(device))
-
-    model_name = 'hfl/chinese-macbert-large'
-    tokenizer = BertTokenizerFast.from_pretrained(model_name)
-    tokenizer.add_special_tokens({'pad_token': '[PAD]'})
-
-    if not os.path.exists(model_save_path):
-        model_dir = os.path.dirname(model_save_path)
-        os.makedirs(model_dir)
-        # Reference:
-        # https://github.com/pytorch/pytorch/blob/b5b62b340891f041b378681577c74922d21700a9/torch/hub.py
-        url = 'https://github.com/cb1cyf/NNER/releases/download/v0.0.1/macbert-large'
-        try:
-            model_base = torch.hub.load_state_dict_from_url(url, model_dir)
-        except:
-            torch.hub.download_url_to_file(url, model_save_path)
-            model_base = torch.load(model_save_path)
-    else:
-        model_base = torch.load(model_save_path)
-    NER = _NamedEntityRecognizer(maxlen, c_size, id2c, device, tokenizer, model_base)
-    NER.predict_to_file(in_file, out_file)
-"""
+    NNER = _NamedEntityRecognizer(maxlen, c_size, id2c, device, tokenizer, model_base)
+    return NNER
 
 
 if __name__ == '__main__':
